#!/usr/bin/fades

import sys

from urllib import request, parse

import bs4  # fades

SUB_URL = "https://subdivx.com/index.php?buscar={}&accion=5&masdesc=&subtitulos=1&realiza_b=1"

EXTENSIONS = {
    'application/x-rar-compressed': '.rar',
}


def _find(soup, to_search):
    """Find a nice subtitle."""
    title_link = None
    for result in soup.find_all("div"):
        if result.attrs.get('id') == "menu_titulo_buscador":
            title_link = result.find('a')['href']

        if result.attrs.get('id') == "buscador_detalle_sub":
            text = result.text.lower()
            if all(x in text for x in to_search):
                return title_link


def _get_link(soup, text):
    """Get link to download."""
    for node in soup.find_all('a'):
        if node.text == text:
            return node['href']


def main(titles):
    for title in titles:
        print("Searching for {!r}".format(title))
        url = SUB_URL.format(parse.quote_plus(title.encode("utf8")))
        raw = request.urlopen(url).read()
        soup = bs4.BeautifulSoup(raw, "html.parser")
        link = _find(soup, ("yify", "argenteam"))
        if link is None:
            link = _find(soup, ("yify",))
            if link is None:
                print("    result not found")
                continue
            else:
                print("    result found for yify only", repr(link))
        else:
            print("    result found for yify and argenteam!", repr(link))

        u = request.urlopen(link)
        raw = u.read()
        soup = bs4.BeautifulSoup(raw, "html.parser")
        link = _get_link(soup, "Bajar subtítulo ahora")
        if link is None:
            print("    direct link not found")
            continue

        print("    direct link found!", repr(link))
        u = request.urlopen(link)
        ct = u.headers['Content-Type']
        print("    size:", u.headers.get('Content-Length'))
        try:
            extension = EXTENSIONS[ct]
        except KeyError:
            print("    WARNING: unknown content type:", repr(ct))
            extension = '.unknown'
        raw = u.read()
        with open(title + extension, 'wb') as fh:
            fh.write(raw)


if __name__ == "__main__":
    if len(sys.argv) == 1:
        print("Usage: sub_yify.py title1 [title2 [...]]")
        exit()
    main(sys.argv[1:])
